@@ -38,18 +38,16 @@ glreg <- function(formula=NULL, remove.redundant=FALSE, Q0=NULL,
     if (intercept_only(formula)) {
       X <- matrix(rep.int(1, e$l), ncol=1L, dimnames=list(NULL, "(Intercept)"))
     } else {
-      #X <- compute_X(formula, data=e$e$data, remove.redundant=remove.redundant, sparse=FALSE)
       X <- model_matrix(formula, e$e$data, sparse=FALSE)
       if (remove.redundant) X <- remove_redundancy(X)
       if (is.null(e$factor)) stop("cannot derive group-level design matrix")
       factor.info <- get_factor_info(e$factor, e$e$data)
-      if ("spline" %in% factor.info$types) stop("unsupported combination: splines and group-level covariates")
+      if (any("spline" == factor.info$types)) stop("unsupported combination: splines and group-level covariates")
       fac <- combine_factors(factor.info$variables, e$e$data)
       X <- economizeMatrix(crossprod(aggrMatrix(fac, mean=TRUE), X), strip.names=FALSE)
       rm(fac)
     }
   } else {  # formula + group-level data provided
-    #X <- compute_X(formula, data=data, remove.redundant=remove.redundant, sparse=FALSE)
     X <- model_matrix(formula, data, sparse=FALSE)
     if (remove.redundant) X <- remove_redundancy(X)
     # TODO if formula is used, match levels of factor to glp$data
